@@ -66,7 +66,7 @@ class Excel:
         writer = pd.ExcelWriter(filename, engine='openpyxl', mode='a', if_sheet_exists=if_sheet_exists)
 
         # get the last row in the existing Excel sheet if it was not specified explicitly
-        if startrow is None:
+        if startrow is None or truncate_sheet is True:
             startrow = 0
         elif startrow is None and sheet_name in writer.book.sheetnames:
             startrow = writer.book[sheet_name].max_row
@@ -94,6 +94,8 @@ class Excel:
             # index of [sheet_name] sheet
             idx = writer.book.sheetnames.index(sheet_name)
             writer.book.worksheets[idx].auto_filter.ref = writer.book.worksheets[idx].dimensions
+        else:
+            writer.book.active.auto_filter.ref = writer.book.active.dimensions
 
         # make columns autofit
         if sheet_name in writer.book.sheetnames:
